@@ -127,6 +127,12 @@
 
 #undef SKALIBS_HASPPOLL
 
+#undef SKALIBS_HASQSORTR_POSIX
+#define SKALIBS_HASQSORTR_POSIX
+
+#undef SKALIBS_HASQSORTR_FREEBSD
+#define SKALIBS_HASQSORTR_FREEBSD
+
 #undef SKALIBS_HASREVOKE
 #define SKALIBS_HASREVOKE
 
@@ -208,6 +214,17 @@
 #undef SKALIBS_HASDLADDR
 #define SKALIBS_HASDLADDR
 
+#undef SKALIBS_HASPIDFD_OPEN
+
+#undef SKALIBS_HASPRCTL
+
+#undef SKALIBS_HASPROCCTL
+
+#undef SKALIBS_HASKEVENT
+#define SKALIBS_HASKEVENT
+
+#undef SKALIBS_HASKQUEUE1
+
 #undef SKALIBS_HASDEVURANDOM
 #define SKALIBS_HASDEVURANDOM
 
